@@ -2,12 +2,17 @@ import importlib
 from .cdn_client import CdnClient
 from .nas_client import NasClient
 from .dds_client import DdsClient
+from .kafka_client import KafkaClient
+from .order_client import OrderClient
 from proxy_tools import proxy
 
+
 prod_mapper = {
     'cdn': CdnClient,
     'nas': NasClient,
-    'dds': DdsClient
+    'dds': DdsClient,
+    'kafka': KafkaClient,
+    'order': OrderClient
 }
 
 
@@ -31,3 +36,13 @@ def nas_client():
 @proxy
 def dds_client():
     return get_current_client('dds')
+
+
+@proxy
+def kafka_client():
+    return get_current_client('kafka')
+
+
+@proxy
+def order_client():
+    return get_current_client('order')
