@@ -9,8 +9,8 @@ from aliyunsdkcdn.request.v20180510.DeleteCdnDomainRequest import DeleteCdnDomai
 
 
 class CdnClient(AliCloudClient):
-    def __init__(self, secret_id, secret_key, region):
-        super(CdnClient, self).__init__(secret_id, secret_key, region)
+    def __init__(self, secret_id, secret_key, region, config):
+        super(CdnClient, self).__init__(secret_id, secret_key, region, config, 'cdn')
 
     def describe_user_domains(self, query_params=None, body_params=None):
         return self.do_request(DescribeUserDomainsRequest, query_params, body_params)
